You can run python code here to access the eyes17 hardware. But this has restrictions, like the output to the console will appear only in the end.

To run proper python programs to access eyes17, copy the directory '/usr/share/eyes17/examples' to the home directory to run the examples. You should exit this GUI before that, the hardware can be accessed by only one <<<<<<< HEAD program at a time. Use python3 to run the code, required modules are installed only for python3. example: $ python3 capture1.py will capture the input at A1 and plot it using matplotlib ======= program at a time.

>>>>>>> f627e49e9aa7aa1dccad7ef4cfb11eac5db09a05